@@ -36,7 +36,7 @@ use Clone 'clone';
 
 use App::Aphra::File;
 
-our $VERSION = '0.0.4';
+our $VERSION = '0.0.5';
 
 has commands => (
   isa => 'HashRef',
@@ -124,7 +124,7 @@ sub _build_template {
   my $self = shift;
 
   my $exts = clone $self->config->{extensions};
-  delete $exts->{template};
+  delete $exts->{tt};
 
   return Template->new(
     LOAD_TEMPLATES => [
